You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@lucene.apache.org by ro...@apache.org on 2023/05/10 08:07:32 UTC

[lucene] branch branch_9_6 updated: Add next bugfix version 9.6.1

This is an automated email from the ASF dual-hosted git repository.

romseygeek pushed a commit to branch branch_9_6
in repository https://gitbox.apache.org/repos/asf/lucene.git


The following commit(s) were added to refs/heads/branch_9_6 by this push:
     new 23747d80315 Add next bugfix version 9.6.1
23747d80315 is described below

commit 23747d80315687d192daaefe48a9ef5fc8692689
Author: Alan Woodward <ro...@apache.org>
AuthorDate: Wed May 10 09:07:27 2023 +0100

    Add next bugfix version 9.6.1
---
 build.gradle                                             |  2 +-
 lucene/CHANGES.txt                                       |  6 ++++++
 lucene/core/src/java/org/apache/lucene/util/Version.java | 11 ++++++++---
 3 files changed, 15 insertions(+), 4 deletions(-)

diff --git a/build.gradle b/build.gradle
index ba77f2ef6d5..c2934bc682a 100644
--- a/build.gradle
+++ b/build.gradle
@@ -36,7 +36,7 @@ apply from: file('gradle/globals.gradle')
 // Calculate project version:
 version = {
   // Release manager: update base version here after release:
-  String baseVersion = '9.6.0'
+  String baseVersion = '9.6.1'
 
   // On a release explicitly set release version in one go:
   //  -Dversion.release=x.y.z
diff --git a/lucene/CHANGES.txt b/lucene/CHANGES.txt
index adc0f4e3502..216d7021a42 100644
--- a/lucene/CHANGES.txt
+++ b/lucene/CHANGES.txt
@@ -3,6 +3,12 @@ Lucene Change Log
 For more information on past and future Lucene versions, please see:
 http://s.apache.org/luceneversions
 
+======================== Lucene 9.6.1 =======================
+
+Bug Fixes
+---------------------
+(No changes)
+
 ======================== Lucene 9.6.0 =======================
 
 API Changes
diff --git a/lucene/core/src/java/org/apache/lucene/util/Version.java b/lucene/core/src/java/org/apache/lucene/util/Version.java
index 3bc4be34d5a..c57bfd6945d 100644
--- a/lucene/core/src/java/org/apache/lucene/util/Version.java
+++ b/lucene/core/src/java/org/apache/lucene/util/Version.java
@@ -259,11 +259,16 @@ public final class Version {
   @Deprecated public static final Version LUCENE_9_5_0 = new Version(9, 5, 0);
 
   /**
-   * Match settings and bugs in Lucene's 9.6.0 release.
+   * @deprecated (9.6.1) Use latest
+   */
+  @Deprecated public static final Version LUCENE_9_6_0 = new Version(9, 6, 0);
+
+  /**
+   * Match settings and bugs in Lucene's 9.6.1 release.
    *
    * <p>Use this to get the latest &amp; greatest settings, bug fixes, etc, for Lucene.
    */
-  public static final Version LUCENE_9_6_0 = new Version(9, 6, 0);
+  public static final Version LUCENE_9_6_1 = new Version(9, 6, 1);
 
   // To add a new version:
   //  * Only add above this comment
@@ -279,7 +284,7 @@ public final class Version {
    * <b>re-test your entire application</b> to ensure it behaves as expected, as some defaults may
    * have changed and may break functionality in your application.
    */
-  public static final Version LATEST = LUCENE_9_6_0;
+  public static final Version LATEST = LUCENE_9_6_1;
 
   /**
    * Constant for backwards compatibility.